Make the RDMA test return XFAIL rather than skip when RXE is not
available, since the RDMA datapath is not run in netdev CI.

Change the three RDMA-prerequisite checks in check_rdma_conf() and
check_rdma_conf_enabled() to exit with the XFAIL code (5) and tag their
messages [XFAIL] instead of [SKIP].

Signed-off-by: Allison Henderson <[email protected]>
---
 tools/testing/selftests/net/rds/rds_run.sh | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/tools/testing/selftests/net/rds/rds_run.sh 
b/tools/testing/selftests/net/rds/rds_run.sh
index c16b30dbdd169..ba957a2257c91 100755
--- a/tools/testing/selftests/net/rds/rds_run.sh
+++ b/tools/testing/selftests/net/rds/rds_run.sh
@@ -123,10 +123,10 @@ check_rdma_conf_enabled() {
                probe_module "$2"
                return
        fi
-       echo "selftests: [SKIP] rdma transport requires $1 enabled"
+       echo "selftests: [XFAIL] rdma transport requires $1 enabled"
        echo "To enable, run" \
             "tools/testing/selftests/net/rds/config.sh -r and rebuild"
-       exit 4
+       exit 5
 }
 
 # Load the module backing a config that is built as a loadable module
@@ -148,7 +148,7 @@ check_conf() {
 }
 
 # Check kernel config and host environment for RDS-RDMA support.
 # Exits with SKIP (4) if the user requested rdma but prerequisites
 # are not met.
 check_rdma_conf()
 {
@@ -163,9 +163,9 @@ check_rdma_conf()
        check_rdma_conf_enabled CONFIG_RDS_RDMA rds_rdma
 
        if ! which rdma > /dev/null 2>&1; then
-               echo "selftests: [SKIP] rdma transport requires the 'rdma'" \
-                     " tool (iproute2)"
-               exit 4
+               echo "selftests: [XFAIL] rdma transport requires the 'rdma'" \
+                     "tool (iproute2)"
+               exit 5
        fi
 }
 
@@ -148,7 +148,7 @@ check_conf() {
 
 # Check kernel config and host environment for RDS-RDMA support.
-# Exits with SKIP (4) if the user requested rdma but prerequisites
+# Exits with XFAIL (5) if the user requested rdma but prerequisites
 # are not met.
 check_rdma_conf()
-- 
2.25.1


Reply via email to